==> mipt2024f_4_barrect-0.0.1.tar.gz: mipt2024f_4_barrect-0.0.1/README.md <==
# mipt2024f-4-koshelev-a

### Описание задачи

Необходимо создать ректификатор изображений штрих кодов.

**Предполагаемый вход:**
1) Сырое изображение в любом из форматов, доступных OpenCV
2) Данные от точного локализатора в формате `json`
    1) Имя входного файла 
    2) Соотношение сторон в формате `double` в виде `width/height`
    3) Предполагаемые размер ширины выходного изображения в пикселях (скорее всего, далее напишу автоопределение по некоторым характеристикам контура)
    4) Массив точек задающих контур в обговоренном формате (обход положительно ориентированный aka внутренность при обходе слева; точки начинаются с левого нижнего угла кода)

**Предполагаемый выход:**

Ректифицированное изображение с заданным соотношением сторон и размером.

### Описание API

На данный момент API выглядит следующим образом:
1) Конфигурационный файл `config.toml`

```toml
[io]
# Директория, выделенная под данные
dataDir = "data"
# Поддиректория, в которую пишется вывод приложения
outDirSuffix = "out"
# Имя входного файла с данными о преобразовании
tasksJsonFileName = "tasks.json"
```

2) Файл с данными в формате `json`

```json lines
{
  "tasks": [
    {
      // Имя входного файла
      "fileName": "warp.jpg",
      // Соотношение сторон ширина/высота выходного изображения
      "ratio": 1.0,
      // Базовый размер (ширина выходного изображения)
      "dimension": 400,
      // Контур, задающий входные данные (пока четырехугольник)
      "polygon": [
        {
          "x": 1252,
          "y": 1196
        },
        {
          "x": 1668,
          "y": 1496
        },
        {
          "x": 1712,
          "y": 1132
        },
        {
          "x": 1336,
          "y": 828
        }
      ]
    }
  ]
}
```

### Простейшее преобразование перспективы

На данный момент реализовано простейшее преобразование перспективы. Пример работы таков:

<img src="data/warp.jpg" alt="Исходное изображение" style="width: 49%; height: auto;"/>
<img src="data/warp_proc.jpg" alt="Обработанное изображение" style="width: 49%; height: auto;"/>

==> mipt2024f_4_barrect-0.0.2.tar.gz: mipt2024f_4_barrect-0.0.2/README.md <==
# mipt2024f-4-koshelev-a

### Описание задачи

Необходимо создать ректификатор изображений штрих кодов.

**Предполагаемый вход:**

```python
def rectify(
        # Входное изображение, прочитанное с помощью OpenCV
        img_src: np.ndarray,
        
        # Контур кода на исходном изображении в обходе эталона кода
        # начиная с левого нижнего угла против часовой стрелки
        border: np.ndarray,
        
        # Соотношение сторон эталона в формате x_ratio к y_ratio
        x_ratio: int = 1,
        y_ratio: int = 1
) 
```

**Предполагаемый выход:**

Ректифицированное изображение с заданным соотношением сторон и подобранным ректификатором размером.

### Документация



На данный момент API выглядит следующим образом:
1) Конфигурационный файл `config.toml`

```toml
[io]
# Директория, выделенная под данные
dataDir = "data"
# Поддиректория, в которую пишется вывод приложения
outDirSuffix = "out"
# Имя входного файла с данными о преобразовании
tasksJsonFileName = "tasks.json"
```

2) Файл с данными в формате `json`

```json lines
{
  "tasks": [
    {
      // Имя входного файла
      "fileName": "warp.jpg",
      // Соотношение сторон ширина/высота выходного изображения
      "ratio": 1.0,
      // Базовый размер (ширина выходного изображения)
      "dimension": 400,
      // Контур, задающий входные данные (пока четырехугольник)
      "polygon": [
        {
          "x": 1252,
          "y": 1196
        },
        {
          "x": 1668,
          "y": 1496
        },
        {
          "x": 1712,
          "y": 1132
        },
        {
          "x": 1336,
          "y": 828
        }
      ]
    }
  ]
}
```

### Простейшее преобразование перспективы

На данный момент реализовано простейшее преобразование перспективы. Пример работы таков:

<img src="data/warp.jpg" alt="Исходное изображение" style="width: 49%; height: auto;"/>
<img src="data/warp_proc.jpg" alt="Обработанное изображение" style="width: 49%; height: auto;"/>
